import click

from vectordash.cli.list import list
from vectordash.cli.secret import secret
from vectordash.cli.ssh import ssh
from vectordash.cli.pull import pull
from vectordash.cli.push import push


@click.group()
def cli():
    """
    Vectordash CLI interacts with Vectordash server and executes your commands.
    More help is available under each command listed below.
    """
    pass


def add_commands(cli):
    cli.add_command(list)
    cli.add_command(secret)
    cli.add_command(ssh)
    cli.add_command(push)
    cli.add_command(pull)


add_commands(cli)



import click
import requests
import json
import os
import subprocess
from colored import fg
from colored import stylize

from vectordash import API_URL, TOKEN_URL


@click.command()
@click.argument('machine', required=True, nargs=1)
def ssh(machine):
    """
    args: <machine>
    Runs an ssh command to the machine to allow user to connect.

    """
    try:
        # retrieve the secret token from the config folder
        dot_folder = os.path.expanduser('~/.vectordash/')
        token = os.path.join(dot_folder, 'token')

        if os.path.isfile(token):
            with open(token) as f:
                secret_token = f.readline()

            # API endpoint for machine information
            full_url = API_URL + str(secret_token)
            r = requests.get(full_url)

            # API connection is successful, retrieve the JSON object
            if r.status_code == 200:
                data = r.json()

                # machine provided is one this user has access to
                if data.get(machine):
                    gpu_mach = (data.get(machine))
                    print(stylize("Connecting to your instance...", fg("green")))

                    # Machine pem
                    pem = gpu_mach['pem']

                    # name for pem key file, formatted to be stored
                    machine_name = (gpu_mach['name'].lower()).replace(" ", "")
                    key_file = os.path.expanduser(dot_folder + machine_name + '-key.pem')

                    # create new file ~/.vectordash/<key_file>.pem to write into
                    with open(key_file, "w") as h:
                        h.write(pem)

                    # give key file permissions for ssh
                    os.chmod(key_file, 0o600)

                    # Port, IP address, and user information for ssh command
                    port = str(gpu_mach['port'])
                    ip = str(gpu_mach['ip'])
                    user = str(gpu_mach['user'])

                    # execute ssh command
                    ssh_command = ["ssh", user + "@" + ip, "-p", port, "-i", key_file]
                    print("Executing " + stylize(" ".join(ssh_command), fg("blue")))
                    try:
                        subprocess.check_call(ssh_command)
                    except subprocess.CalledProcessError:
                        print("Your instance is configuring. Please wait a few seconds!")
                        pass

                else:
                    print(stylize(machine + " is not a valid machine id.", fg("red")))
                    print("Please make sure you are connecting to a valid machine")

            else:
                print(stylize("Could not connect to vectordash API with provided token", fg("red")))

        else:
            # If token is not stored, the command will not execute
            print(stylize("Unable to connect with stored token. Please make sure a valid token is stored.", fg("red")))
            print("Run " + stylize("vectordash secret <token>", fg("blue")))
            print("Your token can be found at " + stylize(str(TOKEN_URL), fg("blue")))

    except TypeError:
        type_err = "There was a problem with ssh. Please ensure your command is of the format "
        print(type_err + stylize("vectordash ssh <id>", fg("blue")))



#!/usr/bin/env python
import os
from setuptools import find_packages, setup

project = "vectordash"
version = "1.1"

with open(os.path.join(os.path.dirname(__file__), 'README.md')) as readme:
    long_description = readme.read()

setup(
    name=project,
    version=version,
    description="Command line interface for interacting with Vectordash GPUs.",
    long_description=long_description,
    author="Arbaz Khatib",
    author_email="contact@vectordash.com",
    url="https://github.com/Vectordash/vectordash-cli",
    packages=find_packages(exclude=["*.tests", "*.tests.*", "tests.*", "tests"]),
    include_package_data=True,
    zip_safe=False,
    keywords="vectordash",
    install_requires=[
        "click>=6.7,<7",
        "requests>=2.18.4",
        "colored>=1.3.5",
    ],
    setup_requires=[],
    dependency_links=[],
    entry_points={
        "console_scripts": [
            "vectordash = vectordash.main:cli",
        ],
    },
)



import click
import requests
import json
import os
from colored import fg
from colored import stylize
from colored import attr

from vectordash import API_URL, TOKEN_URL, VECTORDASH_URL

@click.command()
def list():
    """
    args: None
    Displays the list of machines that user is currently renting

    """
    try:
        token = os.path.expanduser('~/.vectordash/token')

        if os.path.isfile(token):
            with open(token) as f:
                secret_token = f.readline()
                full_url = API_URL + str(secret_token)

            r = requests.get(full_url)

            if r.status_code == 200:
                data = r.json()

                if len(data) > 0:
                    green_bolded = fg("green") + attr("bold")
                    print("Your Vectordash machines:")
                    for key, value in data.items():
                        pretty_id = stylize("[" + str(key) + "]", green_bolded)
                        machine = str(pretty_id) + " " + str(value['name'])
                        print(machine)
                else:
                    vd = stylize(VECTORDASH_URL, fg("blue"))
                    print("You are not currently renting any machines. Go to " + vd + "create/ to start an instance.")
            else:
                print(stylize("Could not connect to Vectordash API with provided token", fg("red")))

        else:
            print(stylize("Unable to locate token. Please make sure a valid token is stored.", fg("red")))
            print("Run " + stylize("vectordash secret <token>", fg("blue")))
            print("Your token can be found at " + stylize(str(TOKEN_URL), fg("blue")))

    except TypeError:
        type_err = "Please make sure a valid token is stored. Run "
        print(type_err + stylize("vectordash secret <token>", fg("blue")))
